# Clips

All visual clip types for video composition. Every clip inherits from the
`Clip` base class and implements `render_frame()`.

## Base

::: pymotion.clip.base.Clip

::: pymotion.clip.base.BlendMode

::: pymotion.clip.base.Resolution

::: pymotion.clip.base.TimeRange

::: pymotion.clip.base.RenderContext

## ColorClip

::: pymotion.clip.color.ColorClip

## GradientClip

::: pymotion.clip.color.GradientClip

## TextClip

::: pymotion.clip.text.TextClip

## ImageClip

::: pymotion.clip.image.ImageClip

## VideoClip

::: pymotion.clip.video.VideoClip

## ShapeClip

::: pymotion.clip.shape.ShapeClip

## AudioClip

::: pymotion.clip.audio.AudioClip

## Scene3DClip

::: pymotion.clip.scene3d.Scene3DClip

::: pymotion.clip.scene3d.Scene3D
